StudyTiling
===========

.. currentmodule:: toasty.study

.. autoclass:: StudyTiling
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~StudyTiling.apply_to_imageset
      ~StudyTiling.compute_for_subimage
      ~StudyTiling.count_populated_positions
      ~StudyTiling.generate_populated_positions
      ~StudyTiling.image_to_tile
      ~StudyTiling.n_deepest_layer_tiles
      ~StudyTiling.tile_image

   .. rubric:: Methods Documentation

   .. automethod:: apply_to_imageset
   .. automethod:: compute_for_subimage
   .. automethod:: count_populated_positions
   .. automethod:: generate_populated_positions
   .. automethod:: image_to_tile
   .. automethod:: n_deepest_layer_tiles
   .. automethod:: tile_image
